@@ -13,6 +13,8 @@ use Class::Type::Enum values => [qw(
 	notify_final
 	finalreview
 	announcing
+	transcribing
+	syncing
 	done
 	injecting
 	remove
